@@ -7,21 +7,21 @@ param = fillParam(param)
 
 param["scaleRandomFields"] = param["range"]/2 
 
-if(abs(param["aniso.ratio"]) >  10^(-4)){
+if(abs(param["anisoRatio"]) >  10^(-4)){
 	# geometric anisotropy
 	scaleTwoDirections = c(1/param["scaleRandomFields"],
-			1/(param["aniso.ratio"]*param["scaleRandomFields"]))
-	angle = param["aniso.angle.radians"]
+			1/(param["anisoRatio"]*param["scaleRandomFields"]))
+	angle = param["anisoAngleRadians"]
 	anisoMat = diag(scaleTwoDirections) %*% 
 			matrix(c(cos(angle), sin(angle), 
 							-sin(angle), cos(angle)),2)
 	model=list("$", var=param["variance"],   
 			A=anisoMat,
-			list("matern", nu=param["rough"]))	
+			list("matern", nu=param["shape"]))	
 } else {
 	model=list("$", var=param["variance"],   
 			s=param["scaleRandomFields"],
-			list("matern", nu=param["rough"]))	
+			list("matern", nu=param["shape"]))	
 }	
 
 model 
@@ -39,14 +39,14 @@ fillParam = function(param) {
 	}
 	
 # fill in anisotropy parameters	
-	if(!any(names(param)=="aniso.ratio"))
-		param["aniso.ratio"] = 1
-	if(!any(names(param)=="aniso.angle.radians")){
-		if(any(names(param)=="aniso.angle.degrees")) {
-			param["aniso.angle.radians"] = 
-					param["aniso.angle.degrees"]*2*pi/360 				
+	if(!any(names(param)=="anisoRatio"))
+		param["anisoRatio"] = 1
+	if(!any(names(param)=="anisoAngleRadians")){
+		if(any(names(param)=="anisoAngleDegrees")) {
+			param["anisoAngleRadians"] = 
+					param["anisoAngleDegrees"]*2*pi/360 				
 		} else {
-			param["aniso.angle.radians"] = 0
+			param["anisoAngleRadians"] = 0
 		}
 	}
 	param
